version 10
clear
capture log close
set more off
set memory 200m
set dp comma

* cd <Arbeitsverzeichnis>

log using Beisp_02.log, text replace

* Diese Datei: Beisp_02.do (30.04.2009)

* Beispiel 2: Designbasierte Schtzung der Zahl der Erwerbsttigen (10 PSUs)

/* Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/Stata_Beispiele.zip */

use ef1 ef3 ef4 ef30 ef504 ef505 ef506 ef712  ///
    if ef3==0187 | ef3==2353 | ef3==3084 | ef3==4353 | ef3==6555 | ///
       ef3==6579 | ef3==7825 | ef3==8517 | ef3==9330 | ef3==9909   ///
    using mz02cf_Beisp.dta, replace 

gen f = 0.01 * 0.035  // Auswahlsatz MZ 1%, CF 3,5%
gen w = 1/f           // Designgewicht

* Subpopulation Bev. in Privathaushalten am Hauptwohnsitz 
*               im Alter von 15 Jahren und lter
gen sub = ef506==1 & ef505>=1 & ef505<=2 & ef30>=15

* Y-Variable: Erwerbsttige
gen y = ef504==1 /* Y-Variable ggf. mit sub multipliz. */

* Individualdaten 
list ef3 y sub w, nolab sepby(ef3)

* Einstufige Klumpenausw., ohne Schichtung, Designgewichtung  
svyset ef3 [pw = w], single(missing) fpc(f)
svy linearized, subpop(sub) : total y 

/*  Berechnen der gewichteten PSU Totals und Anwendung der Stata-Formel im
    SVY-Manual, S. 151-152 sowie der ungewichteten PSU Totals fr Anwendung
    der StBA-Formeln in Fachserie 1 Reihe 4.1.1, Mikrozensus 2002, S. 19 */
collapse (sum)  n_ghi=y , by(ef3) 
gen y_hi = n_ghi * 1/(0.01 * 0.035)
* PSU- bzw. Haushaltsdaten
list , nolab sep(0)

* ==== Umsetzung StBA-Formeln ==== 
scalar f = 0.01 * 0.035  // Auswahlsatz
scalar m_h = _N
sum n_ghi, meanonly
scalar n_quer_gh = 1/_N * r(sum)
egen s2_gh = total((n_ghi - n_quer_gh)^2)
replace s2_gh = 1/(m_h-1) * s2_gh
scalar s2_gh = s2_gh[_N]

* (2) mit (n^2_g / f^2) multiplizieren 
scalar var_y = (1-f) * m_h * s2_gh / (f*f) /* Varianz */
scalar s_y = var_y^.5                   /* Std.fehler */

* (1) mit Designgewichtung 
gen total_y = sum(n_ghi*1/f)            /* Gesamtwert */

display as text "Total:  ", as res total_y[_N], ///
        _newline(1) as text "Std.Abw.:", as res s_y, ///
        _newline(1) as text "CV (%):    ", as res s_y*100/total_y[_N]

* ==== Umsetzung Stata-Formeln ==== 
scalar f_h = 0.01 * 0.035  // Auswahlsatz
scalar n_h = _N
sum y_hi, meanonly
scalar y_quer_h = 1/_N * r(sum)
egen v_y = total((y_hi - y_quer_h)^2)
replace v_y = (1-f_h) * n_h/(n_h-1) * v_y  /* Varianz */
scalar se_y = v_y[_N]^.5                /* Std.fehler */
gen t_y = sum(y_hi)                     /* Gesamtwert */

display as text "Total:  ", as res t_y[_N], ///
        _newline(1) as text "Std.Abw.:", as res se_y, ///
        _newline(1) as text "CV (%):    ", as res se_y*100/t_y[_N]

exit

