version 10
clear
capture log close
set more off
set memory 200m
set dp comma

* cd <Arbeitsverzeichnis>

log using Beisp_03.log, text replace

* Diese Datei: Beisp_03.do (22.05.2008)

* Beispiel 3a: Designeffekte im Campus File 

/* Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/Stata_Beispiele.zip */

use ef1 ef3 ef30 ef504 ef505 ef506 ef507 ef712 ///
    using mz02cf_Beisp.dta, clear

* Schichtung: Bundesland (ef1), Gebudegrenklasse (ef712)
gen schicht = ef1*10 + ef712

gen f = 0.01 * 0.035  // Auswahlsatz MZ 1%, CF 3,5%
gen w = 1/f           // Designgewicht

gen y = ef504==2 // Interessierende Variable: ILO-Erwerbslos (ef504)

* Subpopulation: Bevlkerung am Hauptwohnsitz (ef505), 15+ Jahre (ef30)
gen sub = ef505>=1 & ef505<=2 & ef30>=15

* Beispiel 3a: Designeffekte im Campus File 
svyset ef3 [pw=w] , strata(schicht) fpc(f) singleunit(certainty)
quietly: svy linearized, subpop(sub) : total y
estat effects, deff deft meff meft
matrix v_d = e(V)   /* Designbasierte Varianz */
svmat  v_d

* SRSWOR: Einf. Zufallsstichprobe, Ziehen ohne Zurcklegen
svyset _n [pw=w], fpc(f)
svy linearized, subpop(sub) : total y
matrix v_srswor = e(V)   
svmat  v_srswor

* SRSWR: Einfache Zufallsstichprobe, Ziehen mit Zurcklegen
svyset _n [pw=w] 
svy linearized, subpop(sub) : total y
matrix v_srswr = e(V)
svmat  v_srswr

* SRSWR wie fr Berechnung MEFF und MEFT
total y [pw=w] if sub
matrix v_msp = e(V)
svmat  v_msp

gen DEFF = v_d/v_srswor 
gen DEFT = (v_d/v_srswr)^.5
gen MEFF = v_d/v_msp
gen MEFT = (v_d/v_msp)^.5
list DEFF DEFT MEFF MEFT in 1/1, noobs

exit

/*
* Beispiel 3b: Designeffekte im Scientific Use File MZ 2002
* Stata-Programm wie Beispiel 1 und Beispiel 3a, Y = Erwerbslos
* im SUF abweichende Stichprobendefinitionen 
gen f = 0.01
gen w = 1/(0.01 * 0.70)  /* Designgewicht */
{...}
estat effects, deff deft meff meft

    |          Linearized
    |    Total  Std. Err.    DEFF     DEFT     MEFF     MEFT
----+-------------------------------------------------------
  y |  2930572  23156,14  1,34465  1,15552  1,34622  1,16027
*/
