version 10
clear
capture log close
set more off
set memory 200m
set dp comma

* cd <Arbeitsverzeichnis>

log using Beisp_08.log, text replace

* Diese Datei: Beisp_08.do (22.05.2008)

* Beispiel 8: Erwerbslosenquote mit gebundener Hochrechnung (Poststratifikation)

/* Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/Stata_Beispiele.zip */


use ef1 ef3 ef4 ef30 ef32 ef52 ef127 ef504 ef505 ef708 ef712 ef750g ///
    using mz02cf_Beisp.dta, replace 

* Variablenabgenzungen analog zu Beispiel 4
gen schicht = ef1*10 + ef712 
gen f = 0.01 * 0.035  // Auswahlsatz MZ 1%, CF 3,5%
gen w = 1/f           // Designgewicht

* sub: Bevlkerung am Hauptwohnsitz, 15-65 Jahre, Erwerbspersonen
gen sub = ef505>=1 & ef505<=2 & ef30>=15 & ef30<=65 & ef504>=1 & ef504<=2
gen y = (ef504==2) * sub            // Erwerbslose
gen x = (ef504>=1 & ef504<=2) * sub // Erwerbspersonen

recode ef1 (1/11=1 "West") (*=2 "Ost"), gen(westost)
replace westost = 2 if ef708==9
recode ef30 (0/14=0 "0-14")   (15/24=1 "15-24") ///
            (25/54=2 "25-54") (55/65=3 "55-65") ///
            (66/99=4 "66+"), gen(alter)

* Proxy Anpassungsschicht
gen anp=(1*(ef32==1 & ef52==1 & ef127~=9 & ef127~=10)) /// Deutsche Mnner
      + (2*(ef32==2 & ef52==1)) /// Deutsche Frauen
      + (3*(ef32==1 & ef52~=1)) /// Auslndische Mnner
      + (4*(ef32==2 & ef52~=1)) /// Auslndische Frauen
      + (5*(ef32==1 & ef52==1 & ef127==9)) /// Zeit-/Berufssoldaten
      + (6*(ef32==1 & ef52==1 & ef127==10)) // Wehrpflichtige
gen anpschicht=sub*(ef1*10+anp) /* nur fr Subpop */

* Populationsdaten pro Anpassungsschicht (wie [A] in Beisp_06.do)
egen M_k = total(ef750g*100*(ef505<=2)), by(anpschicht) 

* Erwerbslosenquote nach Altersgruppen 
svyset ef3 [pw = w], strata(schicht) fpc(f) single(certainty) ///
                     poststrata(anpschicht) postweight(M_k) 
svy linearized, subpop(sub) : ratio (Erwerbslosenquote: y/x), ///
                                      over(alter)

* Variationskoeffizienten (cv)
matrix tap = e(b)
matrix vap = e(V)
matrix cvap = sqrt(vap[1,1]) / tap[1,1] , ///
              sqrt(vap[2,2]) / tap[1,2], sqrt(vap[3,3]) / tap[1,3]
matrix list cvap

* Erwerbslosenquote nach Region und Altersgruppen
svy linearized, subpop(sub) : ratio (Erwerbslosenquote: y/x), ///
                                     over(westost alter)

* Wald-Tests 
* Erwerbslosenquote 15-24-Jhriger: West = Ost ?
test [Erwerbslosenquote]_subpop_1 = [Erwerbslosenquote]_subpop_4

* Erwerbslosenquote 55-65-Jhriger: West = Ost ?
test [Erwerbslosenquote]_subpop_3 = [Erwerbslosenquote]_subpop_6

exit

/*
* Beispiel 8: Verhltniswerte bei gebundener Hochrechnung im SUF MZ 2002
* - abweichende Definitionen  -
gen f = 0.01
gen w = 1/(0.01 * 0.70)   // Designgewicht
egen M_k = total(ef750*100/0.7*(ef505<=2)), by(anpschicht) 
(...)
svyset ef3 [pw = w], strata(schicht) fpc(f) single(certainty) ///
                     poststrata(anpschicht) postweight(M_k) 
svy linearized, subpop(sub) : ratio (Erwerbslosenquote: y/x)

--------------------------------------------------------------
             |             Linearized
             |      Ratio   Std. Err.     [95% Conf. Interval]
-------------+------------------------------------------------
Erwerbslos~e |   ,0879048   ,0006554      ,0866203    ,0891894
--------------------------------------------------------------
*/


