version 10
clear
capture log close
set more off
set memory 200m
set dp comma

* cd <Arbeitsverzeichnis>

log using Beisp_11.log, text replace

* Diese Datei: Beisp_11.do (22.05.2008)

* Beispiel 11: Regression des Monatsnettoeinkommens auf Bildung, Geschlecht und Staatsangehrigkeit

/* Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/Stata_Beispiele.zip */


use ef1 ef3 ef4 ef30 ef32 ef52 ef127 ef286 ef287 ef288 ef289 ///
    ef338 ef372 ef504 ef505 ef708 ef712 ef750g ///
   using mz02cf_Beisp.dta, replace 

* Allgemeiner Bildungsabschluss - typische Ausbildungsdauer
recode ef287 (1=9 "[9] Hauptschule") ///
               (2 3=10 "[10] Realschule, POS") ///
               (4=12 "[12] FHR") ///
               (5=13 "[13] Abitur") ///
               (0=8 "[8] ohne Abschluss") ///
               (9=.a "k.A., Entfllt") ///
               (.a=.a "[.a] k.A.Entf"), gen(x287)
replace x287 = .a if (ef286==0 | ef286==9)

* Beruflicher Abschluss - typische Ausbildungsdauer
recode ef289 (0=0 "[0] ohne Abschluss") ///
             (1 2=1 "[1] Anlernausb., BVJ") ///
             (3 7 8=3 "[3] Lehre, FH, Verw.FH") ///
             (4 5 6=2 "[2] BFS, Meister, FS DDR") ///
             (9=5 "[5] Uni") ///
             (10=7 "[7] Prom.")  ///
             (0 99=.a "[.a] k.A., Entfllt"), gen(x289)
replace x289 = .a if ef288==0 | ef288==9

* Rekodierung Nettoeinkommen - Klassenmitte bzw. 
*   obere Randklasse  = 150% * Untergrenze 
recode ef372 (1=75) (2=225) (3=400) (4=600) (5=800) ///
  (6=1000) (7=1200) (8=1400) (9=1600) (10=1850) (11=2150) ///
  (12=2450) (13=2750) (14=3050) (15=3400) (16=3800) (17=4250) ///
  (18=4750) (19=5250) (20=5750) (21=6750) (22=8750) (23=14000) ///
  (24=27000) (50 90 99 = .), gen(v372m)
gen logv372m = ln(v372m)

* Staatsangehrigkeit
recode ef52 (1=1 "[1] Deutsch") (*=2 "[2] Auslnder"), gen(v52)

* sub: Bev. am Hauptwohnsitz, abh. beschftigte Erwerbsttige ///
       (ohne Auszubildende) mit berw. Lebensunterhalt aus ///
       Erwerbsttigkeit und gltigen Bildungs- und Einkommensang. 
gen sub = ef505>=1 & ef505<=2 & ef127>=4 & ef127<=6 & ///
          ef504==1 & ef338==1 & v372m<. & x287<. & x289<.

* (1) OLS (SRSWR)
xi: regress logv372m x287 x289 i.ef32 i.v52 if sub
estat imtest, white
estat hettest, iid

* (2) Robuste Varianzschtzung, Klumpung: Auswahlbezirk (SRSWR)
xi: regress logv372m x287 x289 i.ef32 i.v52 if sub, vce(cluster ef3)

* (3) SVY: Schichtung, Klumpung, Designgewichtung (SRSWOR)
gen schicht = ef1*10 + ef712 
gen f = 0.01 * 0.035  // Auswahlsatz MZ 1%, CF 3,5%
gen w = 1/f           // Designgewicht
svyset ef3 [pw=w] , strata(schicht) fpc(f) singleunit(certainty)
xi: svy: regress logv372m x287 x289 i.ef32 i.v52 if sub

* (4) SVY: Schichtung, Klumpung, gebundene Hochrechnung (SRSWOR)
* Proxy Anpassungsschicht
gen anp=(1*(ef32==1 & ef52==1 & ef127~=9 & ef127~=10)) /// Deutsche Mnner
      + (2*(ef32==2 & ef52==1)) /// Deutsche Frauen
      + (3*(ef32==1 & ef52~=1)) /// Auslndische Mnner
      + (4*(ef32==2 & ef52~=1)) /// Auslndische Frauen
      + (5*(ef32==1 & ef52==1 & ef127==9)) /// Zeit-/Berufssoldaten
      + (6*(ef32==1 & ef52==1 & ef127==10)) // Wehrpflichtige
gen anpschicht=sub*(ef1*10+anp) /* nur fr Subpop */
* Populationsdaten pro Anpassungsschicht (wie [A] in Beisp_06.do)
egen M_k = total(ef750g*100*(ef505<=2)), by(anpschicht) 
svyset ef3 [pw=w] , strata(schicht) fpc(f) singleunit(certainty) poststrata(anpschicht) postweight(M_k)
xi: svy: regress logv372m x287 x289 i.ef32 i.v52 if sub

exit

